; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
;--------------------------------------------------------------------------------------------------------
[Command]
name = "cpu"
command = D, F, U, UF, D, F, x+y
time = 0

[Command]
name = "cpu2"
command = B, F, U, DB, D, F, a+b
time = 0

[Command]
name = "cpu3"
command = B, U, DB, D, F, D, c
time = 0

[Command]
name = "cpu4"
command = F, D, UB, F, B, D, a
time = 0

[Command]
name = "cpu5"
command = F+a, b+c+D, c+x+a+UB
time = 0

[Command]
name = "cpu6"
command = F+b+c, D, UB, c+a, c+x+UF
time = 0

[Command]
name = "cpu7"
command = F, U, B, F, UF, U, B, DF, c+z
time = 0

[Command]
name = "cpu8"
command = F, U, B, F, UF, U, B, DU, c+z
time = 0

[Command]
name = "com"
command = U, U ,D, D, B, F, B, F
time = 80

[Command]
name = "cpu9"
command = F, U, B, F, UF, U, B, D, D, c+z
time = 0

[Command]
name = "cpu10"
command = F, U, B, F, UF, U, B, c+z+UB
time = 0

[Command]
name = "cpu11"
command = F, U, B, F, UF, U, B, c+z+UD
time = 0

[Command]
name = "cpu12"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu13"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu14"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu15"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu16"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu17"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu18"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu19"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu20"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu21"
command = F, U, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu22"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu23"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu24"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu25"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu26"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu27"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu28"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu29"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu30"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu31"
command = F, UD, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu32"
command = F, U, BD, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu33"
command = F, UF, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu34"
command = D, D, D, D, D, D, D, x
time = 1
[Command]
name = "cpu"
command = D, F, U, UF, D, F, x+y
time = 0

[Command]
name = "cpu2"
command = B, F, U, DB, D, F, a+b
time = 0

[Command]
name = "cpu3"
command = B, U, DB, D, F, D, c
time = 0

[Command]
name = "cpu4"
command = F, D, UB, F, B, D, a
time = 0

[Command]
name = "cpu5"
command = F+a, b+c+D, c+x+a+UB
time = 0

[Command]
name = "cpu6"
command = F+b+c, D, UB, c+a, c+x+UF
time = 0

[Command]
name = "cpu7"
command = F, U, B, F, UF, U, B, DF, c+z
time = 0

[Command]
name = "cpu8"
command = F, U, B, F, UF, U, B, DU, c+z
time = 0

[Command]
name = "cpu9"
command = F, U, B, F, UF, U, B, D, D, c+z
time = 0

[Command]
name = "cpu10"
command = F, U, B, F, UF, U, B, c+z+UB
time = 0

[Command]
name = "cpu11"
command = F, U, B, F, UF, U, B, c+z+UD
time = 0

[Command]
name = "cpu12"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu13"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu14"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu15"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu16"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu17"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu18"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu19"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu20"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu21"
command = F, U, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu22"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu23"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu24"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu25"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu26"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu27"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu28"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu29"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu30"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu31"
command = F, UD, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu32"
command = F, U, BD, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu33"
command = F, UF, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu34"
command = D, D, D, D, D, D, D, x
time = 1

[Command]
name = "cpu"
command = D, F, U, UF, D, F, x+y
time = 0

[Command]
name = "cpu2"
command = B, F, U, DB, D, F, a+b
time = 0

[Command]
name = "cpu3"
command = B, U, DB, D, F, D, c
time = 0

[Command]
name = "cpu4"
command = F, D, UB, F, B, D, a
time = 0

[Command]
name = "cpu5"
command = F+a, b+c+D, c+x+a+UB
time = 0

[Command]
name = "cpu6"
command = F+b+c, D, UB, c+a, c+x+UF
time = 0

[Command]
name = "cpu7"
command = F, U, B, F, UF, U, B, DF, c+z
time = 0

[Command]
name = "cpu8"
command = F, U, B, F, UF, U, B, DU, c+z
time = 0

[Command]
name = "cpu9"
command = F, U, B, F, UF, U, B, D, D, c+z
time = 0

[Command]
name = "cpu10"
command = F, U, B, F, UF, U, B, c+z+UB
time = 0

[Command]
name = "cpu11"
command = F, U, B, F, UF, U, B, c+z+UD
time = 0

[Command]
name = "cpu12"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu13"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu14"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu15"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu16"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu17"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu18"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu19"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu20"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu21"
command = F, U, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu22"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu23"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu24"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu25"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu26"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu27"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu28"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu29"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu30"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu31"
command = F, UD, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu32"
command = F, U, BD, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu33"
command = F, UF, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu34"
command = D, D, D, D, D, D, D, x
time = 1
[Command]
name = "cpu"
command = D, F, U, UF, D, F, x+y
time = 0

[Command]
name = "cpu2"
command = B, F, U, DB, D, F, a+b
time = 0

[Command]
name = "cpu3"
command = B, U, DB, D, F, D, c
time = 0

[Command]
name = "cpu4"
command = F, D, UB, F, B, D, a
time = 0

[Command]
name = "cpu5"
command = F+a, b+c+D, c+x+a+UB
time = 0

[Command]
name = "cpu6"
command = F+b+c, D, UB, c+a, c+x+UF
time = 0

[Command]
name = "cpu7"
command = F, U, B, F, UF, U, B, DF, c+z
time = 0

[Command]
name = "cpu8"
command = F, U, B, F, UF, U, B, DU, c+z
time = 0

[Command]
name = "cpu9"
command = F, U, B, F, UF, U, B, D, D, c+z
time = 0

[Command]
name = "cpu10"
command = F, U, B, F, UF, U, B, c+z+UB
time = 0

[Command]
name = "cpu11"
command = F, U, B, F, UF, U, B, c+z+UD
time = 0

[Command]
name = "cpu12"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu13"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu14"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu15"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu16"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu17"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu18"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu19"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu20"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu21"
command = F, U, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu22"
command = F, U, B, F, UF, U, B, a+b
time = 0

[Command]
name = "cpu23"
command = F, U, B, F, UF, U, B, c+y
time = 0

[Command]
name = "cpu24"
command = F, U, B, F, UF, U, B, c+x
time = 0

[Command]
name = "cpu25"
command = F, U, B, F, UF, U, B, c+b
time = 0

[Command]
name = "cpu26"
command = F, U, B, F, UF, U, B, c+a
time = 0

[Command]
name = "cpu27"
command = F, U, B, F, UF, U, B, c+z+b
time = 0

[Command]
name = "cpu28"
command = F, U, B, F, UF, U, B, c+z+a
time = 0

[Command]
name = "cpu29"
command = F, U, B, F, UF, U, B, c+z+x
time = 0

[Command]
name = "cpu30"
command = F, U, B, F, UF, U, B, c+z+B
time = 0

[Command]
name = "cpu31"
command = F, UD, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu32"
command = F, U, BD, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu33"
command = F, UF, B, F, UF, U, B, c+z+y
time = 0

[Command]
name = "cpu34"
command = D, D, D, D, D, D, D, x
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "uE"
command = ~x, x, F, a, y
time = 30

[Command]
name = "S"
command = ~F, D, B, F, D, B, a
time = 30

[Command]
name = "S"
command = ~F, D, B, F, D, B, b
time = 30

[Command]
name = "S"
command = ~F, D, B, c

[Command]
name = ""
command = ~D, F, D, B, x
time = 25

[Command]
name = ""
command = ~D, F, D, B, y
time = 25

[Command]
name = "`"
command = ~D, F, D, F,s
time = 25

[Command]
name = "fire"
command = ~D, F, D, F,x+y
time = 25

[Command]
name = "ŎE"
command = ~D, F, D, F,x
time = 25

[Command]
name = "ŎE"
command = ~D, F, D, F,y
time = 25

[Command]
name = "ŎE2"
command = ~F, D, DF, z

[Command]
name = "^E"
command = ~D, F, D, F,c
time = 25

[Command]
name = "j"
command = ~D, F, D, F,a
time = 25

[Command]
name = "j"
command = ~D, F, D, F,b
time = 25

[Command]
name = "ŎEg"
command = ~D, B, D, B, x
time = 25

[Command]
name = "ŎEg2"
command = ~D, B, D, B, y
time = 25

[Command]
name = "ꌂKE"
command = ~D, B, D, B, x+y
time = 25

[Command]
name = "ŎEg3"
command = ~D, DF, F, z

[Command]
name = "nage"
command = ~F, D, B, F, a
time = 25

[Command]
name = "nage"
command = ~F, D, B, F, b
time = 25

[Command]
name = ""
command = ~D, B, D, B, a
time = 25

[Command]
name = ""
command = ~D, B, D, B, b
time = 25

[Command]
name = ""
command = ~D, D, D, x+y
time = 25

[Command]
name = "p`n"
command = ~D, D, D, x
time = 25

[Command]
name = "p`n"
command = ~D, D, D, y
time = 25

[Command]
name = ""
command = ~D, DB, B, z

[Command]
name = "e"
command = ~F, B, D, F, x
time = 25

[Command]
name = "e"
command = ~F, B, D, F, y
time = 25

[Command]
name = "e"
command = ~D, DF, F, c
time = 25

[Command]
name = ""
command = ~D, B, D, F, x
time = 25

[Command]
name = ""
command = ~D, B, D, F, y
time = 25

[Command]
name = ""
command = ~D, DB, B, c
time = 25

;-| Special Motions |------------------------------------------------------


[Command]
name = "C"
command = ~F, D, DF, x+y

[Command]
name = "C2"
command = ~B, D, DB, x+y

[Command]
name = "C3"
command = ~F, D, DF, a+b

[Command]
name = "C4"
command = ~B, D, DB, a+b

[Command]
name = ""
command = ~F, D, DF, x

[Command]
name = "2"
command = ~F, D, DF, y

[Command]
name = "3"
command = ~F, D, DF, c

[Command]
name = "_bV"
command = ~F, D, DF, a

[Command]
name = "_bV2"
command = ~F, D, DF, b

[Command]
name = "g"
command = ~D, DF, F, x

[Command]
name = "g2"
command = ~D, DF, F, y

[Command]
name = "S"
command = ~D, DF, F, a+b

[Command]
name = "Ŏ"
command = ~D, DF, F, a

[Command]
name = "Ŏ2"
command = ~D, DF, F, b

[Command]
name = "ܔM"
command = ~F, D, B, x

[Command]
name = "ܔM2"
command = ~F, D, B, y

[Command]
name = "hangeki"
command = ~D, DB, B, x

[Command]
name = "hangeki"
command = ~D, DB, B, y

[Command]
name = "Đg"
command = ~B, D, DB, x

[Command]
name = "Đg"
command = ~B, D, DB, y

[Command]
name = "SS"
command = ~B, D, DB, a

[Command]
name = "SS2"
command = ~B, D, DB, b

[Command]
name = ""
command = ~D, DB, B, a

[Command]
name = "2"
command = ~D, DB, B, b


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "Hjump"
command = $D, $U
time = 13

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+a
time = 1

[Command]
name = "bc"
command = a+y
time = 1

[Command]
name = "push"
command = x+y
time = 1

[Command]
name = "dodge"
command = x+a
time = 1

[Command]
name = "ko"
command = y+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "recovery"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdx"
command = /$x
time = 1

[Command]
name = "holdy"
command = /$y
time = 1

[Command]
name = "holda"
command = /$a
time = 1

[Command]
name = "holdb"
command = /$b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------


[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1320
triggerall = command = "uE"
triggerall = power >= 2000
triggerall = var(58) = 0
triggerall = var(59) = 0
triggerall = var(55) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201
trigger3 = stateno = 211
trigger4 = stateno = 230
trigger5 = stateno = 242
trigger6 = stateno = 410
trigger7 = stateno = 430
trigger8 = stateno = 411
trigger9 = stateno = 440
trigger10 = stateno = 200 || stateno = 201
trigger11 = stateno = 210 || stateno = 211
trigger12 = stateno = 230 || stateno = 231
trigger13 = stateno = 242 || stateno = 212
trigger14 = stateno = 441&&movecontact
trigger15 = stateno = 241&&movecontact

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1320
triggerall = command = "uE"
triggerall = power >= 3000
triggerall = var(59) = 0
triggerall = var(58) = 1
triggerall = var(55) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201
trigger3 = stateno = 211
trigger4 = stateno = 230
trigger5 = stateno = 242
trigger6 = stateno = 410
trigger7 = stateno = 430
trigger8 = stateno = 411
trigger9 = stateno = 440
trigger10 = stateno = 200 || stateno = 201
trigger11 = stateno = 210 || stateno = 211
trigger12 = stateno = 230 || stateno = 231
trigger13 = stateno = 242 || stateno = 212
trigger14 = stateno = 441&&movecontact
trigger15 = stateno = 241&&movecontact

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 2030
triggerall = command = "uE"
triggerall = power >= 3000
triggerall = var(59) = 0
triggerall = var(55) = 1
trigger1 = statetype != A
trigger1 = stateno = 210
trigger2 = stateno = 201
trigger3 = stateno = 211
trigger4 = stateno = 230
trigger5 = stateno = 242
trigger6 = stateno = 410
trigger7 = stateno = 430
trigger8 = stateno = 411
trigger9 = stateno = 440
trigger10 = stateno = 200 || stateno = 201
trigger11 = stateno = 210 || stateno = 211
trigger12 = stateno = 230 || stateno = 231
trigger13 = stateno = 242 || stateno = 212
trigger14 = stateno = 441&&movecontact
trigger15 = stateno = 241&&movecontact
trigger16 = stateno = 20

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = command = "S"
triggerall = var(59) = 0
triggerall = var(58) = 0 && power >= 3000 || var(58) = 1 && power >= 2000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201
trigger2 = movecontact
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1400
triggerall = command = ""
triggerall = power >= 2000
triggerall = var(59) = 0
triggerall = var(58) = 1
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1940
triggerall = command = "`"
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = var(55) = 1
triggerall = statetype != A
trigger1 = ctrl

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 2100
triggerall = command = "fire"
triggerall =  var(58) = 1
triggerall = power >= 2000
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1


[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1200
triggerall = command = "ŎE"  || command = "ŎE2"
triggerall =  var(55) = 0
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1200
triggerall = var(55) = 1
triggerall = command = "j" || command = "ŎE2"
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 2040
triggerall = command = "ŎE" || command ="ŎEg3"
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = var(55) = 1
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1500
triggerall = command = "^E"
triggerall = var(58) = 1
triggerall = power >= 2000
triggerall = var(59) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1640
triggerall = command = "j"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm];ichigeki
type = ChangeState
value = 1870
triggerall = command = "ŎEg"
triggerall = var(59) = 0
triggerall = var(55) = 1
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm];ichigeki
type = ChangeState
value = 2060
triggerall = command = "ŎEg2"
triggerall = var(59) = 0
triggerall = var(55) = 1
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1220
triggerall = command = "ŎEg"
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = var(55) = 0
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1230
triggerall = command = "ŎEg2" || command = "ŎEg3"
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = var(55) = 0
triggerall = numproj = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1250
triggerall = command = "ŎE" || command = "ŎEg3"
triggerall = numproj = 0
triggerall = var(59) = 0
triggerall = var(55) = 0
triggerall = power >= 1000
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1010&&movecontact
trigger3 = stateno = 1013&&movecontact
trigger4 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1250
triggerall = command = "ŎE" || command = "ŎEg2"
triggerall = numproj = 0
triggerall = var(59) = 1
triggerall = var(55) = 0
triggerall = power >= 1000
triggerall = statetype = A
triggerall = p2bodydist x  > 20
triggerall = P2BodyDist y > -100
trigger1 = ctrl
trigger2 = stateno = 1010&&movecontact
trigger3 = stateno = 1013&&movecontact
trigger4 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1600
triggerall = command = ""
triggerall = var(58) = 1
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1090
triggerall = command = "nage"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 2050
triggerall = command = ""
triggerall = var(55) = 1
triggerall = power >= 1000
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1010&&movecontact
trigger13 = stateno = 1013&&movecontact
trigger14 = stateno = 1890&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1700
triggerall = command = "p`n"
triggerall = var(55) = 1
triggerall = power >= 1000
triggerall = var(59) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
;trigger11 = stateno = 1010&&movecontact  
;trigger12 = stateno = 1013&&movecontact  
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm];a
type = ChangeState
value = 2000
triggerall = command = ""
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1620
triggerall = command = "e"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = power >= 1000
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1630
triggerall = command = ""
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = power >= 1000
triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

;----------------------------------------------------------------------
;----------------------------------------------------------------------
;----------------------------------------------------------------------

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1260
triggerall = command = "C"
triggerall = var(59) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1270
triggerall = command = "C2"
triggerall = var(59) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1280
triggerall = command = "C3"
triggerall = var(55) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1290
triggerall = command = "C4"
triggerall = var(55) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = command = ""
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1013
triggerall = command = "2"
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1890
triggerall = command = "3"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1


[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1342
triggerall = command = "_bV"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1210&&animelem = 7, >= 0 &&var(58) = 1
trigger13 = stateno = 1211&&animelem = 7, >= 0 &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1340
triggerall = command = "_bV2"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1
trigger12 = stateno = 1210&&animelem = 7, >= 0
trigger12 = stateno = 1210&&animelem = 8, <= 3
trigger13 = stateno = 1211&&animelem = 7, >= 0
trigger13 = stateno = 1211&&animelem = 8, <= 3

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1210
triggerall = command = "g"
triggerall = numproj = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1211
triggerall = command = "g2"
triggerall = numproj = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = null;ChangeState
value = 1670
triggerall = command = "S"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1610
triggerall = command = "Ŏ" || command = "Ŏ2"
triggerall = var(58) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm];v~ATC
type = ChangeState
value = 2070
triggerall = command = "Ŏ"
triggerall = var(55) = 1
triggerall = numproj = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm];v~ATC2
type = ChangeState
value = 2080
triggerall = command = "Ŏ2"
triggerall = var(55) = 1
triggerall = numproj = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1710
triggerall = command = "Đg"
triggerall = var(59) = 0
triggerall = var(58) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1212
triggerall = command = "ܔM"
triggerall = numproj = 0
triggerall = var(55) = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1213
triggerall = command = "ܔM2"
triggerall = numproj = 0
triggerall = var(55) = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 2200
triggerall = command = "hangeki"
triggerall = var(55) = 1
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1240
triggerall = command = "g"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl
triggerall = var(55) = 0

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1241
triggerall = command = "g2"
triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl
triggerall = var(55) = 0

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1650
triggerall = command = "SS"
triggerall = var(55) = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1665
triggerall = command = "SS2"
triggerall = var(55) = 0
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1310
triggerall = command = ""
triggerall = var(59) = 0
triggerall = var(55) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1300
triggerall = command = "2"
triggerall = var(59) = 0
triggerall = var(55) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 2010
triggerall = command = ""
triggerall = var(59) = 0
triggerall = var(55) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 2020
triggerall = command = "2"
triggerall = var(59) = 0
triggerall = var(55) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 242&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1315
triggerall = command = "" || command = "2"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;CSVC
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist x  < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist x  < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;D
[State -1, Kung Fu Throw]
type = ChangeState
value = 815
triggerall = command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist x  < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist x  < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
[State -3]
type = varset
trigger1 = command = "com"
trigger1 = roundstate = 1
var(51) = 1
;===========================================================================

[State -1, Kung Fu Throw]
type = ChangeState
value = 212
triggerall = command = "x"
triggerall = statetype = S
triggerall = stateno != 100
triggerall = var(59) = 0
triggerall = var(55) = 0
trigger1 = command = "holdfwd"
trigger1 = ctrl

[State -1, Kung Fu Throw]
type = ChangeState
value = 242
triggerall = command = "a"
triggerall = statetype != A
triggerall = stateno != 100
triggerall = var(59) = 0
triggerall = var(55) = 0
trigger1 = ctrl
triggerall = command = "holdfwd"
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 230&&movecontact
trigger6 = stateno = 410&&movecontact
trigger7 = stateno = 430&&movecontact
trigger8 = stateno = 411&&movecontact
trigger9 = stateno = 440&&movecontact
trigger10 = stateno = 441&&movecontact 
trigger11 = stateno = 241&&movecontact &&var(58) = 1

[State -1, Kung Fu Throw]
type = ChangeState
value = 243
triggerall = command = "c"
triggerall = command = "holdfwd"
triggerall = statetype != A
triggerall = stateno != 100
triggerall = var(59) = 0
triggerall = var(58) = 1
trigger1 = ctrl


[State -1, Kung Fu Throw]
type = ChangeState
value = 441
triggerall = command = "a"
triggerall = command = "holdback"
triggerall = command = "holddown"
triggerall = statetype != A
triggerall = var(59) = 0
triggerall = var(55) = 0
trigger1 = ctrl
trigger2 = stateno = 201&&movecontact
trigger3 = stateno = 211&&movecontact
trigger4 = stateno = 230&&movecontact
trigger5 = stateno = 410&&movecontact
trigger6 = stateno = 430&&movecontact
trigger7 = stateno = 411&&movecontact
trigger8 = stateno = 440&&movecontact

;---------------------------------------------------------------------------
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
triggerall = var(59) = 0


;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF" || command = "bc"
trigger1 = statetype != A
trigger1 = stateno = [150,153] 
trigger1 = power >= 1000
triggerall = var(59) = 0

;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x > 25
trigger2 = p2bodydist x > 25 && var(58) = 1
trigger2 = movecontact && stateno = 230
triggerall = var(59) = 0

;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 201
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x <= 25
trigger2 = p2bodydist x <= 25
trigger2 = movecontact && stateno = 230 && var(58) = 1

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x > 25
trigger2 = p2bodydist x > 25
trigger2 = movecontact && stateno = 201 && var(58) = 1
trigger3 = p2bodydist x  > 25
trigger3 = movecontact && stateno = 230 && var(58) = 1
trigger4 = p2bodydist x  > 25
trigger4 = movecontact && stateno = 410 && var(58) = 1
trigger5 = p2bodydist x  > 25
trigger5 = movecontact && stateno = 430 && var(58) = 1
trigger6 = p2bodydist x  > 25
trigger6 = movecontact && stateno = 241 && var(58) = 1

;---------------------------------------------------------------------------
;Stand Strong Punch
;ߋp`
[State -1, Stand Strong Punch]
type = ChangeState
value = 211
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x  <= 25
trigger2 = p2bodydist x  <= 25
trigger2 = movecontact && stateno = 201 && var(58) = 1
trigger3 = p2bodydist x  <= 25
trigger3 = movecontact && stateno = 230 && var(58) = 1
trigger4 = p2bodydist x  <= 25
trigger4 = movecontact && stateno = 410 && var(58) = 1
trigger5 = p2bodydist x  <= 25
trigger5 = movecontact && stateno = 430 && var(58) = 1
trigger6 = p2bodydist x  <= 25
trigger6 = movecontact && stateno = 241 && var(58) = 1

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 231
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x  > 25
trigger2 = p2bodydist x > 25
trigger2 = movecontact && stateno = 201 && var(58) = 1

;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x  <= 25
trigger2 = p2bodydist x <= 25
trigger2 = movecontact && stateno = 201 && var(58) = 1
;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x  > 25
trigger2 = p2bodydist x > 25
trigger2 = movecontact && stateno = 201 && var(58) = 1
trigger3 = p2bodydist x  > 25
trigger3 = movecontact && stateno = 230 && var(58) = 1
trigger4 = p2bodydist x  > 25
trigger4 = movecontact && stateno = 410 && var(58) = 1
trigger5 = p2bodydist x  > 25
trigger5 = movecontact && stateno = 430 && var(58) = 1

;ߋLbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 241
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = p2bodydist x  <= 25
trigger2 = p2bodydist x  <= 25
trigger2 = movecontact && stateno = 201 && var(58) = 1
trigger3 = p2bodydist x  <= 25
trigger3 = movecontact && stateno = 230 && var(58) = 1
trigger4 = p2bodydist x  <= 25
trigger4 = movecontact && stateno = 410 && var(58) = 1
trigger5 = p2bodydist x  <= 25
trigger5 = movecontact && stateno = 430 && var(58) = 1

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = var(55) = 0
trigger1 = ctrl

;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 1740
triggerall = command = "start"
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = var(55) = 1
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 410
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact && stateno = 430 && var(58) = 1
triggerall = var(59) = 0
;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 411
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact && stateno = 201 && var(58) = 1
trigger3 = movecontact && stateno = 230 && var(58) = 1
trigger4 = movecontact && stateno = 410 && var(58) = 1
trigger5 = movecontact && stateno = 430 && var(58) = 1
trigger6 = movecontact && stateno = 441 && var(58) = 1
trigger7 = movecontact && stateno = 241 && var(58) = 1

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact && stateno = 410 && var(58) = 1

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact && stateno = 201 && var(58) = 1
trigger3 = movecontact && stateno = 230 && var(58) = 1
trigger4 = movecontact && stateno = 410 && var(58) = 1
trigger5 = movecontact && stateno = 430 && var(58) = 1
trigger6 = movecontact && stateno = 441 && var(58) = 1
trigger7 = movecontact && stateno = 211 && var(58) = 1
trigger8 = movecontact && stateno = 241 && var(58) = 1

[State -1, Run Fwd]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = stateno = [150,153]
trigger1 = power >= 1000
trigger1 = statetype != A


;Jump Light Punch
;Wvo[
[State -1, Jump Light Punch]
type = ChangeState
value = 642
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X > 0
triggerall = var(59) = 0
triggerall = var(55) = 0

;Wv
[State -1, Taunt]
type = ChangeState
value = 1930
triggerall = command = "start"
trigger1 = statetype = A
trigger1 = var(55) = 1
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Punch
;Wvp`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X != 0
triggerall = var(59) = 0

;Jump Light Punch
;Wvp`
[State -1, Jump Light Punch]
type = ChangeState
value = 601
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X = 0
triggerall = var(59) = 0
;---------------------------------------------------------------------------
;Wvp`
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X != 0
triggerall = var(59) = 0

;Wvp`
[State -1, Jump Strong Punch]
type = ChangeState
value = 611
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X = 0
triggerall = var(59) = 0

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X != 0
triggerall = var(59) = 0

;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 631
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X = 0
triggerall = var(59) = 0

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X != 0

;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 641
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Vel X = 0

